package com.itseasy.rtf;

import com.itseasy.rtf.RTFAbstractDocument;
import com.itseasy.rtf.text.Font;
import com.itseasy.rtf.text.InfoGroup;
import com.itseasy.rtf.text.PageDefinition;
import com.itseasy.rtf.text.PageSize;
import com.itseasy.rtf.text.Paragraph;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

public class RTFDocument extends RTFAbstractDocument {
   public static final int VIEWSCALE_FULLPAGE = -1;
   public static final int VIEWSCALE_BESTFIT = -2;
   public static final int VIEWKIND_NONE = 0;
   public static final int VIEWKIND_PAGELAYOUT = 1;
   public static final int VIEWKIND_OUTLINE = 2;
   public static final int VIEWKIND_MASTERDOCUMENT = 3;
   public static final int VIEWKIND_NORMAL = 4;
   public static final int VIEWKIND_ONLINELAYOUT = 5;
   private InfoGroup info;
   private List paragraph;
   private List header;
   private List footer;
   private Font deffont;
   private PageDefinition pagedef;
   private int viewscale;
   private int viewkind;

   public RTFDocument() {
      this(PageSize.DIN_A4);
   }

   public RTFDocument(PageSize ps) {
      this.info = new InfoGroup();
      this.paragraph = new ArrayList();
      this.header = new ArrayList();
      this.footer = new ArrayList();
      this.pagedef = new PageDefinition(ps, 20.0D, 20.0D, 20.0D, 20.0D);
      this.deffont = Font.ARIAL;
   }

   public void setDefaultFont(Font font) {
      this.deffont = font;
   }

   public void setViewscale(int zoom) {
      this.viewscale = zoom;
   }

   public void setViewkind(int mode) {
      this.viewkind = mode;
   }

   protected String getDocumentAsString() {
      return "{" + this.getHeader() + this.getDocInfo() + this.getPageDefinition().getRtfContent() + this.getDocView() + this.getHeaderFooterContent() + this.getContent() + "}";
   }

   private String getHeader() {
      return "\\rtf1\\ansi\\ansicpg1252\\deff" + this.deffont.getFontnumber() + "{" + this.getFonttable() + "}" + "{" + this.getColortable() + "}" + "{\\*\\generator " + "SimpleRTFWriter V0.6 by it-s-easy.com" + ";}";
   }

   private String getDocView() {
      StringBuffer result = new StringBuffer();
      if(this.viewscale > 0 && this.viewscale != 100) {
         result.append("\\viewscale" + this.viewscale);
      } else if(this.viewscale == -1) {
         result.append("\\viewzk1");
      } else if(this.viewscale == -2) {
         result.append("\\viewzk2");
      }

      if(this.viewkind > 0) {
         result.append("\\viewkind" + this.viewkind);
      }

      return result.toString();
   }

   private String getFonttable() {
      HashSet fonts = new HashSet();
      Iterator it = this.paragraph.iterator();

      Set content;
      while(it.hasNext()) {
         content = ((Paragraph)it.next()).getAllFonts();
         if(content != null) {
            fonts.addAll(content);
         }
      }

      if(this.header.size() > 0) {
         it = this.header.iterator();

         while(it.hasNext()) {
            content = ((Paragraph)it.next()).getAllFonts();
            if(content != null) {
               fonts.addAll(content);
            }
         }
      }

      if(this.footer.size() > 0) {
         it = this.footer.iterator();

         while(it.hasNext()) {
            content = ((Paragraph)it.next()).getAllFonts();
            if(content != null) {
               fonts.addAll(content);
            }
         }
      }

      StringBuffer content1 = new StringBuffer();
      if(fonts.size() > 0) {
         content1.append("\\fonttbl");
         Iterator fsit = fonts.iterator();

         while(fsit.hasNext()) {
            Font nextfnt = (Font)fsit.next();
            if(nextfnt != null) {
               content1.append("{" + nextfnt.getRtfContent() + "}");
            }
         }
      }

      return content1.toString();
   }

   private String getColortable() {
      return "\\colortbl;\\red0\\green0\\blue0;\\red0\\green0\\blue255;\\red0\\green255\\blue255;\\red0\\green255\\blue0;\\red255\\green0\\blue255;\\red255\\green0\\blue0;\\red255\\green255\\blue0;\\red255\\green255\\blue255;\\red0\\green0\\blue128;\\red0\\green128\\blue128;\\red0\\green128\\blue0;\\red128\\green0\\blue128;\\red128\\green0\\blue0;\\red128\\green128\\blue0;\\red128\\green128\\blue128;\\red192\\green192\\blue192;";
   }

   private String getDocInfo() {
      return this.info.getRtfContent();
   }

   public PageDefinition getPageDefinition() {
      return this.pagedef;
   }

   private String getContent() {
      StringBuffer content = new StringBuffer();
      Iterator it = this.paragraph.iterator();

      while(it.hasNext()) {
         content.append(((Paragraph)it.next()).getRtfContent());
      }

      return content.toString();
   }

   private String getHeaderFooterContent() {
      StringBuffer content = new StringBuffer();
      Iterator it;
      if(this.header.size() > 0) {
         content.append("{\\header ");
         it = this.header.iterator();

         while(it.hasNext()) {
            content.append(((Paragraph)it.next()).getRtfContent());
         }

         content.append("}");
      }

      if(this.footer.size() > 0) {
         content.append("{\\footer ");
         it = this.footer.iterator();

         while(it.hasNext()) {
            content.append(((Paragraph)it.next()).getRtfContent());
         }

         content.append("}");
      }

      return content.toString();
   }

   public InfoGroup getInfo() {
      return this.info;
   }

   public void addParagraph(Paragraph para) {
      this.paragraph.add(para);
   }

   public void addHeader(Paragraph para) {
      this.header.add(para);
   }

   public void addFooter(Paragraph para) {
      this.footer.add(para);
   }
}
