package com.itseasy.rtf.text;

import com.itseasy.rtf.text.Border;
import com.itseasy.rtf.text.Font;
import com.itseasy.rtf.text.Tabulator;
import com.itseasy.rtf.text.Text;
import com.itseasy.rtf.text.TextPart;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.ListIterator;
import java.util.Set;

public class Paragraph {
   public static final String ALIGN_CENTER = "qc";
   public static final String ALIGN_JUSTIFIED = "qj";
   public static final String ALIGN_LEFT = "ql";
   public static final String ALIGN_RIGHT = "qr";
   java.util.List content;
   java.util.List tabulator;
   Border border;
   private String align;
   private boolean newpage;
   private int spacebefore;
   private int spaceafter;
   private Font font;
   private int fontsize;

   public Paragraph() {
      this.newpage = false;
      this.spacebefore = 0;
      this.spaceafter = 0;
      this.fontsize = 0;
      this.content = new ArrayList();
      this.tabulator = new ArrayList();
      this.align = "ql";
   }

   public Paragraph(Text content) {
      this();
      this.addText(content);
   }

   public Paragraph(int spacebefore, int spaceafter, TextPart content) {
      this();
      this.addText(content);
      this.spacebefore = spacebefore;
      this.spaceafter = spaceafter;
   }

   public Paragraph(int spacebefore, int spaceafter) {
      this();
      this.spacebefore = spacebefore;
      this.spaceafter = spaceafter;
   }

   public Paragraph(int spacebefore, int spaceafter, int fontsize, Font font) {
      this();
      this.spacebefore = spacebefore;
      this.spaceafter = spaceafter;
      this.fontsize = fontsize;
      this.font = font;
   }

   public Paragraph(int spacebefore, int spaceafter, int fontsize, Font font, TextPart content) {
      this(spacebefore, spaceafter, content);
      this.fontsize = fontsize;
      this.font = font;
   }

   public void setSapceBefore(int points) {
      this.spacebefore = points;
   }

   public int getSpaceBefore() {
      return this.spacebefore;
   }

   public void setSapceAfter(int points) {
      this.spaceafter = points;
   }

   public int getSpaceAfter() {
      return this.spaceafter;
   }

   public void setNewPageBefore(boolean value) {
      this.newpage = value;
   }

   public void setAlignment(String value) {
      this.align = value;
   }

   public int getFontsize() {
      return this.fontsize;
   }

   public void setFontsize(int size) {
      this.fontsize = size;
   }

   public Font getFont() {
      return this.font;
   }

   public void setFont(Font font) {
      this.font = font;
   }

   public Set getAllFonts() {
      HashSet fs = new HashSet();
      if(this.getFont() != null) {
         fs.add(this.getFont());
      }

      ListIterator it = this.content.listIterator();

      while(it.hasNext()) {
         Set f = ((Text)it.next()).getAllFonts();
         if(f != null) {
            fs.addAll(f);
         }
      }

      return fs.size() > 0?fs:null;
   }

   public void addText(Text part) {
      this.content.add(part);
   }

   public void addTabulator(Tabulator tab) {
      this.tabulator.add(tab);
   }

   public void setBorder(Border border) {
      this.border = border;
   }

   protected String getContent() {
      StringBuffer sb = new StringBuffer();
      ListIterator it = this.content.listIterator();

      while(it.hasNext()) {
         sb.append(((Text)it.next()).getRtfContent());
      }

      return sb.toString();
   }

   protected String getTabulatorDefinitions() {
      StringBuffer sb = new StringBuffer();
      ListIterator it = this.tabulator.listIterator();

      while(it.hasNext()) {
         sb.append(((Tabulator)it.next()).getRtfContent());
      }

      return sb.toString();
   }

   public String getRtfContent() {
      return this.getRtfContent(false);
   }

   public String getRtfContent(boolean insideTable) {
      return "\\pard\\plain" + (insideTable?"\\intbl":"") + "\\" + this.align + "\\faauto" + (this.newpage?"\\pagebb":"") + (this.spacebefore > 0?"\\sb" + this.spacebefore * 10 * 2:"") + (this.spaceafter > 0?"\\sa" + this.spaceafter * 10 * 2:"") + (this.border != null?this.border.getRtfContent():"") + this.getTabulatorDefinitions() + (this.font != null?"\\f" + this.font.getFontnumber():"") + (this.fontsize > 0?"\\fs" + this.fontsize * 2:"") + this.getContent() + "\\par";
   }
}
